package com.mortals.xhx.modules.information.listener;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.mortals.xhx.common.utils.SnowFlakeUtil;
import com.mortals.xhx.modules.supplement.dao.SupplementDao;
import com.mortals.xhx.modules.supplement.model.SupplementEntity;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Wz
 * @Date: 2021-07-2021/7/30-15:06
 * @Description:
 */
@Slf4j
public class InformationDataConversionListener extends AnalysisEventListener<SupplementEntity> {

    /**
     * 每隔5条存储数据库，实际使用中可以3000条，然后清理list ，方便内存回收
     */
    private static final int BATCH_COUNT = 3000;

    /**
     * 这个集合用于接收 读取Excel文件得到的数据
     */
    List<SupplementEntity> entityList=new ArrayList<SupplementEntity>();

    private SupplementDao supplementDao;

    public InformationDataConversionListener(SupplementDao supplementDao){
        this.supplementDao=supplementDao;
    }

    @Override
    public void invoke(SupplementEntity supplementEntity, AnalysisContext analysisContext) {
        //调用方法生成临时表，在数据清洗后删除临时表
        supplementEntity.setId(SnowFlakeUtil.get().nextId());
        entityList.add(supplementEntity);
        //达到BATCH_COUNT了，需要去存储一次数据库，防止数据几万条数据在内存，容易OOM
        if (entityList.size() >= BATCH_COUNT) {
            supplementDao.insertBatch(entityList);
            //存储完成清理list
            entityList.clear();
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {
        supplementDao.insertBatch(entityList);
        log.info("=======Excel文件<<>>导入成功===========");
    }
}

