package com.mortals.xhx.modules.information.task;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.service.ITask;
import com.mortals.framework.service.ITaskExcuteService;
import com.mortals.xhx.common.code.NodeTypeEnum;
import com.mortals.xhx.modules.information.model.EgIfResult;
import com.mortals.xhx.modules.information.model.InformationEntity;
import com.mortals.xhx.modules.information.service.InformationService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Wz
 * @Date: 2021-08-2021/8/3-16:28
 * @Description:办件数据推送省一体化平台(申请并受理)
 */
@Slf4j
@Component("applyAndAcceptInformationTaskImpl")
public class ApplyAndAcceptInformationTaskImpl implements ITaskExcuteService {
    @Autowired
    private InformationService informationService;
    @Override
    public void excuteTask(ITask task) throws AppException {
        //组装申请并受理数据推送一体化平台
        this.applyAndAccept();
    }

    @Override
    public void stopTask(ITask task) throws AppException {

    }

    private void applyAndAccept(){
        InformationEntity informationEntity = new InformationEntity();
        informationEntity.setNodeType(NodeTypeEnum.受理.getCode());
        //查询转化表的数据
        List<InformationEntity> informationEntities = informationService.find(informationEntity, null);
        if (informationEntities.size() > 0){
            informationEntities.forEach(e->{
                Map<String, Object> dataMap = new HashMap<>(16);
                dataMap.put("operateType", "1");

                HashMap<String, Object> targetConditionDefMap = new HashMap<>(16);
                targetConditionDefMap.put("provinceAreaCode", "510000000000");
                targetConditionDefMap.put("deptCode", e.getDeptCode());
                targetConditionDefMap.put("areaCode", e.getAreaCode());
                dataMap.put("targetConditionDef", targetConditionDefMap);

                HashMap<String, Object> baseInfoMap = new HashMap<>(16);
                baseInfoMap.put("reCode", e.getEventCode());
                baseInfoMap.put("bizStatus", e.getBizStatus());
                baseInfoMap.put("sysCode", e.getBizStatus());
                dataMap.put("baseInfo", baseInfoMap);

                HashMap<String, Object> valueMap = new HashMap<>(16);
                HashMap<String, Object> infoMap = new HashMap<>(16);
                infoMap.put("affairName", e.getAffairName());
                infoMap.put("eventCode", e.getEventCode());
                infoMap.put("applyType", e.getApplyType());
                infoMap.put("bizStatus", e.getBizStatus());
                infoMap.put("doThingProperty", e.getDoThingProperty());
                infoMap.put("isCharge", e.getIsCharge());
                infoMap.put("applyNum", e.getApplyNum());
                infoMap.put("applicantType", e.getApplicantAttributes());
                infoMap.put("cardType", e.getApplicantCardType());
                infoMap.put("applicantIdCard", e.getApplicantCardNumbe());
                infoMap.put("applicantName", e.getApplicantName());
                infoMap.put("applicantAddress", "地址不详，未提供");
                infoMap.put("applicantPhone", e.getApplicantPhoneNumber());
                infoMap.put("applicantSex", e.getApplicantSex());
                infoMap.put("contactName", e.getContactName());
                infoMap.put("contactSex", e.getApplicantSex());
                infoMap.put("contactIdCard", e.getContactIdCard());
                infoMap.put("contactCardType", e.getContactCardType());
                infoMap.put("contactPhone", e.getContactPhone());
                HashMap<String, Object> rlogisticsinfoMap = new HashMap<>(16);
                rlogisticsinfoMap.put("pickupType", e.getPickupType());
                infoMap.put("rlogisticsinfo", rlogisticsinfoMap);
                HashMap<String, Object> rprojectruntaskMap = new HashMap<>(16);
                rprojectruntaskMap.put("nodeType", e.getNodeType());
                rprojectruntaskMap.put("addUserId", e.getAddUserId());
                rprojectruntaskMap.put("curHandlerName", StringUtils.isEmpty(e.getCurHandlerName())?"公安厅":e.getCurHandlerName());
                rprojectruntaskMap.put("auditAdvice", e.getAuditAdvice());
                rprojectruntaskMap.put("auditRemark", e.getAuditRemark());
                rprojectruntaskMap.put("genTime",  new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(e.getGenTime()));
                rprojectruntaskMap.put("completeTime", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(e.getCompleteTime()));
                valueMap.put("rprojectsl", infoMap);
                valueMap.put("rprojectruntask", rprojectruntaskMap);
                dataMap.put("value", valueMap);
                try {
                    String post = HttpUtil.post("", dataMap);
                    EgIfResult egIfResult = JSON.parseObject(post, EgIfResult.class);
                    if ("200".equals(egIfResult.getCode())){
                        e.setIsReport("1");
                        e.setIsSuccess("1");
                        e.setOfficeCode(egIfResult.getIfResultInfo());
                        e.setBizStatus(NodeTypeEnum.审查.getDesc());
                        e.setNodeType(NodeTypeEnum.审查.getCode());
                        e.setProcessStatusName("审查");
                        informationService.update(e,null);
                        log.info("推送一体化成功，办件编码："+egIfResult.getIfResultInfo());
                    }else {
                        e.setFailTimes(e.getFailTimes() + 1);
                        e.setFailReason(egIfResult.getIfResultInfo());
                        informationService.update(e,null);
                        log.info("省一体化数据推送失败：" + egIfResult.getIfResultInfo());
                    }
                }catch (Exception ex){
                    log.info("省一体化数据推送失败：连接异常");
                }
            });
        }else {
            log.info("没有从办件表中获取到特定数据");
        }

    }
}
