package com.mortals.xhx.modules.information.task;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.service.ITask;
import com.mortals.framework.service.ITaskExcuteService;
import com.mortals.xhx.common.code.NodeTypeEnum;
import com.mortals.xhx.modules.information.model.EgIfResult;
import com.mortals.xhx.modules.information.model.InformationEntity;
import com.mortals.xhx.modules.information.service.InformationService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Wz
 * @Date: 2021-08-2021/8/3-16:28
 * @Description:办件数据推送省一体化平台（决定）
 */
@Slf4j
@Component("decideInformationTaskImpl")
public class DecideInformationTaskImpl implements ITaskExcuteService {
    @Autowired
    private InformationService informationService;
    @Override
    public void excuteTask(ITask task) throws AppException {
        //组装决定数据推送一体化平台
        this.decideData();
    }

    @Override
    public void stopTask(ITask task) throws AppException {

    }

    private void decideData(){
        InformationEntity informationEntity = new InformationEntity();
        informationEntity.setNodeType(NodeTypeEnum.决定.getCode());
        //查询转化表的数据
        List<InformationEntity> informationEntities = informationService.find(informationEntity, null);
        if (informationEntities.size() > 0){
            informationEntities.forEach(e->{
                HashMap<String, Object> dataMap = new HashMap<>(16);
                dataMap.put("operateType", "1");
                HashMap<String, Object> targetConditionDefMap = new HashMap<>(16);
                targetConditionDefMap.put("provinceAreaCode", "510000000000");
                targetConditionDefMap.put("deptCode", e.getDeptCode());
                targetConditionDefMap.put("areaCode", e.getAreaCode());
                dataMap.put("targetConditionDef", targetConditionDefMap);

                HashMap<String, Object> baseInfoMap = new HashMap<>(16);
                baseInfoMap.put("reCode", e.getEventCode());
                baseInfoMap.put("code", e.getOfficeCode());
                baseInfoMap.put("sysCode", "000L");
                baseInfoMap.put("bizStatus", e.getBizStatus());
                dataMap.put("baseInfo", baseInfoMap);

                HashMap<String, Object> valueMap = new HashMap<>(16);
                HashMap<String, Object> rlogisticsinfoMap = new HashMap<>(16);
                rlogisticsinfoMap.put("nodeType", e.getNodeType());
                rlogisticsinfoMap.put("addUserId", "-1");
                rlogisticsinfoMap.put("curHandlerName", e.getCurHandlerName());
                rlogisticsinfoMap.put("auditAdvice", "1");
                rlogisticsinfoMap.put("auditRemark", "同意");
                rlogisticsinfoMap.put("genTime", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(e.getGenTime()));
                rlogisticsinfoMap.put("completeTime", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(e.getCompleteTime()));
                valueMap.put("rprojectruntask", rlogisticsinfoMap);
                dataMap.put("value", valueMap);

                try {
                    String post = HttpUtil.post("", dataMap);
                    EgIfResult egIfResult = JSON.parseObject(post, EgIfResult.class);
                    if ("200".equals(egIfResult.getCode())){
                        e.setBizStatus(NodeTypeEnum.办结.getDesc());
                        e.setNodeType(NodeTypeEnum.办结.getCode());
                        e.setProcessStatusName("办结");
                        informationService.update(e,null);
                        log.info("推送一体化成功，办件编码："+egIfResult.getIfResultInfo());
                    }else {
                        e.setFailTimes(e.getFailTimes() + 1);
                        e.setFailReason(egIfResult.getIfResultInfo());
                        informationService.update(e,null);
                        log.info("省一体化数据推送失败：" + egIfResult.getIfResultInfo());
                    }
                }catch (Exception ex){
                    log.info("省一体化数据推送失败：连接异常");
                }
            });
        }else {
            log.info("没有从办件表中获取到特定数据");
        }

    }
}
