package com.mortals.xhx.modules.supplement.task;

import cn.hutool.core.date.DateTime;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.service.ITask;
import com.mortals.framework.service.ITaskExcuteService;
import com.mortals.framework.util.DateUtils;
import com.mortals.xhx.common.code.ApplicantTypeEnums;
import com.mortals.xhx.common.code.NodeTypeEnum;
import com.mortals.xhx.common.utils.DateByAffairUtils;
import com.mortals.xhx.common.utils.FilterSuppDataUtils;
import com.mortals.xhx.common.utils.SnowFlakeUtil;
import com.mortals.xhx.modules.implementlist.model.ImplementlistEntity;
import com.mortals.xhx.modules.implementlist.model.ImplementlistQuery;
import com.mortals.xhx.modules.implementlist.service.ImplementlistService;
import com.mortals.xhx.modules.information.dao.InformationDao;
import com.mortals.xhx.modules.information.model.InformationQuery;
import com.mortals.xhx.modules.supplement.dao.SupplementDao;
import com.mortals.xhx.modules.supplement.model.SupplementEntity;
import com.mortals.xhx.modules.supplement.model.SupplementQuery;
import com.mortals.xhx.modules.supplement.service.SupplementService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author Wz
 * @Date: 2021-08-2021/8/2-10:44
 * @Description:数据清洗
 */
@Slf4j
@Component("supplementTaskImpl")
public class SupplementTaskImpl implements ITaskExcuteService {

    @Autowired
    private SupplementService supplementService;

    @Autowired
    private ImplementlistService implementlistService;

    @Autowired
    private InformationDao informationDao;

    @Autowired
    private SupplementDao supplementDao;

    @Override
    public void excuteTask(ITask task) throws AppException {
        //开始进行数据清洗
        this.dataCleaning();
    }

    @Override
    public void stopTask(ITask task) throws AppException {

    }

    private void dataCleaning() {
        //查询临时数据表数据
        List<SupplementEntity> supplementEntities = supplementService.find(new SupplementEntity(),null);
        if (supplementEntities.size() > 0){
            supplementEntities.forEach(e->{
                //TODO：查询实施清单信息，通过事项编码查询有问题，后期改动
                ImplementlistQuery implementlistQuery = new ImplementlistQuery();
                implementlistQuery.setEventCode(e.getImplCode());
                List<ImplementlistEntity> implementlistEntities = implementlistService.find(implementlistQuery, null);
                try {
                    InformationQuery informationQuery = new InformationQuery();
                    //组装第一次业务数据（清洗后的）
                    informationQuery = assemblyOfficeData(informationQuery,e);
                    if (implementlistEntities.size() > 0 ){
                        informationQuery.setDeptCode(implementlistEntities.get(0).getDeptCode());
                        informationQuery.setAreaCode(implementlistEntities.get(0).getAreaCode());
                        informationQuery.setEventCode(implementlistEntities.get(0).getEventCode());
                        informationQuery.setIsCharge(implementlistEntities.get(0).getIsCharges());
                        //是否转化成功：0默认 1成功
                        informationQuery.setIsSuccess("0");
                        //是否推送（0 否 1是）
                        informationQuery.setIsReport("0");
                        informationDao.insert(informationQuery);
                        //清洗成功后，清除临时表的所有数据
                        supplementDao.delete(e.getId());
                    }else {
                        informationQuery.setFailReason(" Err:实施清单不存在");
                        informationQuery.setIsSuccess("0");
                        informationDao.insert(informationQuery);
                    }
                }catch (Exception ex){
                    log.error("转换失败:SupplementID:"+e.getId());
                    log.error("转换失败：失败原因" + ex.getMessage());
                }
            });
        }else {
            log.info("没有从临时表中获取到数据");
        }
    }

    private InformationQuery assemblyOfficeData(InformationQuery informationQuery,SupplementEntity supplementEntity) {
        Date randomDate = DateByAffairUtils.getDayWorkingTimeByRandom(null,9,17);
        informationQuery.setId(SnowFlakeUtil.get().nextId());
        //默认为0：网络办件
        informationQuery.setApplyType("0");
        informationQuery.setAffairName(supplementEntity.getImplName()+ DateUtils.getDateTimeStr(randomDate,null));
        //申请人属性,1：法人 2：自然人
        informationQuery.setApplicantAttributes(Integer.valueOf(supplementEntity.getApplicationType()));
        //申请人证件类型
        informationQuery.setApplicantCardType(supplementEntity.getApplicationCardType());
        //申请人证件号码
        informationQuery.setApplicantCardNumbe(supplementEntity.getApplicationId().trim());
        //申请人手机号码
        informationQuery.setApplicantPhoneNumber(supplementEntity.getApplicationPhone().trim());
        //申请人姓名
        informationQuery.setApplicantName(supplementEntity.getApplicationName().trim());
        //申请人性别
        informationQuery.setApplicantSex(FilterSuppDataUtils.parseGender(supplementEntity.getApplicationId().trim()));
        //无论是否是自然人还是都直接将申请人copy到联系人
        informationQuery.setContactCardType(supplementEntity.getApplicationCardType());
        informationQuery.setContactIdCard(supplementEntity.getApplicationId().trim());
        informationQuery.setContactName(supplementEntity.getApplicationName().trim());
        informationQuery.setContactPhone(supplementEntity.getApplicationPhone().trim());
        //TODO 时间这里可以修改下，最好在一段区间范围内
        informationQuery.setGenTime(randomDate);
        informationQuery.setCompleteTime(DateByAffairUtils.getTimeByAddRandom(randomDate,6));
        if(supplementEntity.getApplicationType().equals(ApplicantTypeEnums.LEGAL.getCode())){
            //法人
            informationQuery.setContactName(supplementEntity.getLegalPerson().trim());
            informationQuery.setContactIdCard(supplementEntity.getMechanismId().trim());
            informationQuery.setContactCardType(supplementEntity.getMechanismIdType());
            informationQuery.setContactPhone(supplementEntity.getApplicationPhone().trim());
            informationQuery.setApplyNum(supplementEntity.getMechanismType()); //临时征用  机构性质
        }
        //设置受理人
        informationQuery.setAcceptId(supplementEntity.getAcceptId());
        informationQuery.setAcceptName(supplementEntity.getAcceptName());
        informationQuery.setAcceptPhone(supplementEntity.getAcceptPhone());
        informationQuery.setCurHandlerName(supplementEntity.getAcceptName());
        informationQuery.setIsReport("0");
        informationQuery.setIsCharge("0");
        //测试暂时写死
        informationQuery.setSystemCode("0000");
        informationQuery.setNodeType(NodeTypeEnum.受理.getCode());
        informationQuery.setBizStatus(NodeTypeEnum.受理.getDesc());
        informationQuery.setProcessStatusName("申请并受理");

        informationQuery.setCreateTime(DateTime.now());
        informationQuery.setUpdateTime(informationQuery.getCreateTime());
        return informationQuery;
    }
}
